==> tuia-advert-center-api-1.5.0-20180622.060357-13-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/RspAppSlotDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2018年03月06日 14:30
 * @descript:
 * @version: 1.0
 */
public class RspAppSlotDto {

    private Long soltId;

    private String soltName;

    private Integer soltStatus;

    /**
     * 发券量
     */
    private Long yesterLaunch;

    /**
     * 屏蔽策略
     */
    private String shieldContent;

    /**
     * 昨日CVR
     */
    private Double yesterCVR;

    /**
     * 是否被选中
     */
    private boolean ifCheck;

    //作弊流量诊断结果高危、中危、正常，高危、中危、正常
    private String slotFlowRiskResult;

    public String getSlotFlowRiskResult() {
        return slotFlowRiskResult;
    }

    public void setSlotFlowRiskResult(String slotFlowRiskResult) {
        this.slotFlowRiskResult = slotFlowRiskResult;
    }

    public Long getSoltId() {
        return soltId;
    }

    public void setSoltId(Long soltId) {
        this.soltId = soltId;
    }

    public String getSoltName() {
        return soltName;
    }

    public void setSoltName(String soltName) {
        this.soltName = soltName;
    }

    public Integer getSoltStatus() {
        return soltStatus;
    }

    public void setSoltStatus(Integer soltStatus) {
        this.soltStatus = soltStatus;
    }

    public Long getYesterLaunch() {
        return yesterLaunch;
    }

    public void setYesterLaunch(Long yesterLaunch) {
        this.yesterLaunch = yesterLaunch;
    }

    public String getShieldContent() {
        return shieldContent;
    }

    public void setShieldContent(String shieldContent) {
        this.shieldContent = shieldContent;
    }

    public Double getYesterCVR() {
        return yesterCVR;
    }

    public void setYesterCVR(Double yesterCVR) {
        this.yesterCVR = yesterCVR;
    }

    public boolean isIfCheck() {
        return ifCheck;
    }

    public void setIfCheck(boolean ifCheck) {
        this.ifCheck = ifCheck;
    }
}

==> tuia-advert-center-api-2.0.0-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/RspAppSlotDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp;

import java.io.Serializable;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2018年03月06日 14:30
 * @descript:
 * @version: 1.0
 */
public class RspAppSlotDto  implements Serializable {

    private static final long serialVersionUID = -7953488597814868009L;
    private Long soltId;

    private String soltName;

    private Integer soltStatus;

    /**
     * 发券量
     */
    private Long yesterLaunch;

    /**
     * 屏蔽策略
     */
    private String shieldContent;

    /**
     * 昨日CVR
     */
    private Double yesterCVR;

    /**
     * 是否被选中
     */
    private boolean ifCheck;

    //作弊流量诊断结果高危、中危、正常，高危、中危、正常
    private String slotFlowRiskResult;

    public String getSlotFlowRiskResult() {
        return slotFlowRiskResult;
    }

    public void setSlotFlowRiskResult(String slotFlowRiskResult) {
        this.slotFlowRiskResult = slotFlowRiskResult;
    }

    public Long getSoltId() {
        return soltId;
    }

    public void setSoltId(Long soltId) {
        this.soltId = soltId;
    }

    public String getSoltName() {
        return soltName;
    }

    public void setSoltName(String soltName) {
        this.soltName = soltName;
    }

    public Integer getSoltStatus() {
        return soltStatus;
    }

    public void setSoltStatus(Integer soltStatus) {
        this.soltStatus = soltStatus;
    }

    public Long getYesterLaunch() {
        return yesterLaunch;
    }

    public void setYesterLaunch(Long yesterLaunch) {
        this.yesterLaunch = yesterLaunch;
    }

    public String getShieldContent() {
        return shieldContent;
    }

    public void setShieldContent(String shieldContent) {
        this.shieldContent = shieldContent;
    }

    public Double getYesterCVR() {
        return yesterCVR;
    }

    public void setYesterCVR(Double yesterCVR) {
        this.yesterCVR = yesterCVR;
    }

    public boolean isIfCheck() {
        return ifCheck;
    }

    public void setIfCheck(boolean ifCheck) {
        this.ifCheck = ifCheck;
    }
}
